@@ -3,7 +3,7 @@ package Net::Lumberjack::Frame;
 use Moose;
 
 # ABSTRACT: class for parsing Lumberjack protocol frames
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 use Net::Lumberjack::Frame::WindowSize;
 use Net::Lumberjack::Frame::Compressed;
@@ -27,12 +27,18 @@ sub new_from_fh {
 	my ( $class, $fh ) = ( shift, shift );
 	my ( $version, $type );
   # EOF not supported by IO::Socket::SSL
-  #if( $fh->eof ) {
-  #  return;
-  #}
+  if( ref($fh) eq 'IO::Socket::SSL') {
+    if( ! $fh->pending ) {
+      return;
+    }
+  } else {
+    if( $fh->eof ) {
+      return;
+    }
+  }
   if( ! $fh->read( $version, 1 ) || ! $fh->read( $type, 1 ) ) {
     die('lost connection');
-	}
+  }
 
   if( ! defined $FRAME_TYPES{$type} ) {
     die('Unknown Lumberjack frame type: '.$type.'('.ord($type).')');
@@ -88,7 +94,7 @@ Net::Lumberjack::Frame - class for parsing Lumberjack protocol frames
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 AUTHOR
 
